@@ -24,7 +24,7 @@
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: postgresql_stubs.c,v 1.10 2004/12/21 03:41:42 mottl Exp $ */
+/* $Id: postgresql_stubs.c,v 1.11 2005/03/22 18:42:17 mottl Exp $ */
 
 #include <string.h>
 
@@ -222,8 +222,9 @@ CAMLprim value PQconnectdb_stub(value vconn_info)
   PGconn *conn;
   value vconn;
 
-  char *conn_info = malloc((string_length(vconn_info) + 1));
-  strcpy(conn_info, String_val(vconn_info));
+  int len = string_length(vconn_info) + 1;
+  char *conn_info = malloc(len);
+  memcpy(conn_info, String_val(vconn_info), len);
 
   caml_enter_blocking_section();
     conn = PQconnectdb(conn_info);
